#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 blaze-textual
version:              0.2.3.1
visibility:           public
id:                   blaze-textual-0.2.3.1-Fzl38G9hmovBIuCNT8qhA8
key:                  blaze-textual-0.2.3.1-Fzl38G9hmovBIuCNT8qhA8
license:              BSD-3-Clause
copyright:            Copyright 2011 MailRank, Inc.
maintainer:           Andrey Prokopenko <persiantiger@yandex.ru>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             http://github.com/swamp-agr/blaze-textual
synopsis:             Fast rendering of common datatypes
description:
    A library for efficiently rendering Haskell datatypes to
    bytestrings.

    /Note/: if you use GHCi or Template Haskell, please see the
    @README@ file for important details about building this package,
    and other packages that depend on it:
    <https://github.com/swamp-agr/blaze-textual#readme>

category:             Text
abi:                  73dddf12d1bf78999d76f512d50e2e52
exposed:              True
exposed-modules:      Blaze.Text Blaze.Text.Double Blaze.Text.Int
hidden-modules:       Blaze.Text.Double.Native
import-dirs:          /usr/lib/ghc-9.6.6/site-local/blaze-textual-0.2.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/blaze-textual-0.2.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/blaze-textual-0.2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-blaze-textual
hs-libraries:         HSblaze-textual-0.2.3.1-Fzl38G9hmovBIuCNT8qhA8
depends:
    base-4.18.2.1 blaze-builder-0.4.4.1-FYNuD9u6a8N9Y4Gg0dDbwR
    bytestring-0.11.5.3 ghc-prim-0.10.0 integer-gmp-1.1
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC text-2.0.2
    vector-0.13.2.0-5YxFBFTVtOB5p4D1EBw8Kb

haddock-interfaces:
    /usr/share/doc/haskell-blaze-textual/html/blaze-textual.haddock

haddock-html:         /usr/share/doc/haskell-blaze-textual/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

